@@ -1,23 +1,23 @@
 import csv
-from datetime import datetime
-from os import path
-from json import dumps
-from httplib2 import Http
-from google.cloud import bigquery
-from google.oauth2 import service_account
+from datetime import datetime as _datetime
+from os import path as _path
+from json import dumps as _dumps
+from httplib2 import Http as _Http
+from google.cloud import bigquery as _bigquery
+from google.oauth2 import service_account as _service_account
 import requests
 import pandas as pd
 from pandas import _DataFrame
-from pandas.io.json import json_normalize
-from cryptography.fernet import Fernet
+from pandas.io.json import json_normalize as _json_normalize
+from cryptography.fernet import Fernet as _Fernet
 
 # BigQuery Lib Methods
 class GCloud:
     def __init__(self, projectName, cred_filepath):
         self.Project = projectName
-        if path.exists(cred_filepath):
+        if _path.exists(cred_filepath):
             try:
-                cred = service_account.Credentials.from_service_account_file(cred_filepath)
+                cred = _service_account.Credentials.from_service_account_file(cred_filepath)
                 self.Credentials = cred
             except Exception as ex:
                 raise ex
@@ -25,7 +25,7 @@ class GCloud:
             raise FileNotFoundError("Error: Big Query Credential File Not Found")
 
     def CreateTable_fromCSV(self, csv_filepath, new_tablename, getSchemaFromTable=None, getSchemaForColumns=None):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
         if getSchemaFromTable is not None:
             if getSchemaForColumns is not None:
                 a = bq_client.query("select {} from {} limit 1".format(getSchemaForColumns, getSchemaFromTable))
@@ -34,24 +34,24 @@ class GCloud:
 
             schema = a.result().schema
 
-            jobConfig = bigquery.LoadJobConfig(
+            jobConfig = _bigquery.LoadJobConfig(
                 schema = schema,
                 allow_jagged_rows = True,
                 allow_quoted_newlines = True,
                 ignore_unknown_values = True,
                 skip_leading_rows = 1,
-                source_format = bigquery.SourceFormat.CSV
+                source_format = _bigquery.SourceFormat.CSV
             )
         else:
-            jobConfig = bigquery.LoadJobConfig(
+            jobConfig = _bigquery.LoadJobConfig(
                 autodetect = True,
                 allow_jagged_rows = True,
                 allow_quoted_newlines = True,
                 ignore_unknown_values = True,
                 skip_leading_rows = 1,
-                source_format = bigquery.SourceFormat.CSV
+                source_format = _bigquery.SourceFormat.CSV
             )
-        if path.exists(csv_filepath):
+        if _path.exists(csv_filepath):
             try:
                 with open(csv_filepath, "rb") as file:
                     job = bq_client.load_table_from_file(file, new_tablename, job_config=jobConfig)
@@ -63,15 +63,15 @@ class GCloud:
             raise FileNotFoundError("FileNotFound")
 
     def CreateTable_fromDataFrame(self, dataFrameTable, new_tablename, schema):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
 
-        jobConfig = bigquery.LoadJobConfig(
+        jobConfig = _bigquery.LoadJobConfig(
             schema = schema,
             allow_jagged_rows=True,
             allow_quoted_newlines=True,
             ignore_unknown_values=True,
             write_disposition="WRITE_TRUNCATE",
-            source_format=bigquery.SourceFormat.CSV
+            source_format=_bigquery.SourceFormat.CSV
         )
 
         try:
@@ -82,13 +82,13 @@ class GCloud:
             return ex
 
     def CreateTable_fromJSON(self, json, newTableName, schema):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
 
-        jobConfig = bigquery.LoadJobConfig(
+        jobConfig = _bigquery.LoadJobConfig(
             schema = schema,
             ignore_unknown_values=True,
             write_disposition="WRITE_TRUNCATE",
-            source_format=bigquery.SourceFormat.NEWLINE_DELIMITED_JSON
+            source_format=_bigquery.SourceFormat.NEWLINE_DELIMITED_JSON
         )
         try:
             job = bq_client.load_table_from_json(json, newTableName, job_config=jobConfig)
@@ -99,13 +99,13 @@ class GCloud:
 
     def DeleteTable(self, tableName):
         try:
-            bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+            bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
             bq_client.delete_table(tableName, not_found_ok=True)
         except Exception as ex:
             raise ex
 
     def GetTableSchema(self, getSchemaFromTable, getSchemaForColumns=None):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
 
         if getSchemaForColumns is not None:
             a = bq_client.query("select {} from {} limit 1".format(getSchemaForColumns, getSchemaFromTable))
@@ -115,8 +115,8 @@ class GCloud:
         return a.result().schema
 
     def DryRun(self, query):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
-        job_config = bigquery.QueryJobConfig(
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
+        job_config = _bigquery.QueryJobConfig(
             dry_run=True,
             use_query_cache=False
         )
@@ -127,7 +127,7 @@ class GCloud:
             raise ex
 
     def GetData(self, query):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
         try:
             job = bq_client.query(query)
             job.result()
@@ -136,7 +136,7 @@ class GCloud:
             raise ex
 
     def GetData_asDataFrame(self, query):
-        bq_client = bigquery.Client(project=self.Project, credentials=self.Credentials)
+        bq_client = _bigquery.Client(project=self.Project, credentials=self.Credentials)
         try:
             job = bq_client.query(query)
             job.result()
@@ -164,7 +164,7 @@ class ServiceNow:
                 raise Exception("Error 200: Service Now query returned with error")
 
             #bigQueryObj = GCloud("irm-eit-infra-ops", 'E:\\keys\\irm-eit-infra-ops-da41c8a4bb41.json')
-            #bigQueryObj.CreateTable_fromDataFrame(pd.json_normalize(json.loads(response.content), record_path=["result"]),"SWTest.testTable")
+            #bigQueryObj.CreateTable_fromDataFrame(pd._json_normalize(json.loads(response.content), record_path=["result"]),"SWTest.testTable")
             data = response.json()
             return data
         except Exception as ex:
@@ -197,7 +197,7 @@ class SolarwindsOperations:
 class CommonOperations:
     def convertJSONtoCSV(self, jsondata, csvFilePath):
         try:
-            dt = json_normalize(jsondata)
+            dt = _json_normalize(jsondata)
             dt = dt.reindex(sorted(dt.columns), axis=1)
             dt.to_csv(csvFilePath, index=False, quoting=csv.QUOTE_ALL)
         except Exception as ex:
@@ -281,7 +281,7 @@ class CommonOperations:
                                                 {
                                                     "keyValue": {
                                                         "topLabel": "UTC Time",
-                                                        "content": datetime.utcnow().strftime("%m/%d/%Y, %H:%M:%S"),
+                                                        "content": _datetime.utcnow().strftime("%m/%d/%Y, %H:%M:%S"),
                                                         "contentMultiline": "false",
                                                         "icon": "MAP_PIN"
                                                     }
@@ -295,13 +295,13 @@ class CommonOperations:
 
         message_headers = {'Content-Type': 'application/json; charset=UTF-8'}
 
-        http_obj = Http()
+        http_obj = _Http()
 
         response = http_obj.request(
             uri=url,
             method='POST',
             headers=message_headers,
-            body=dumps(bot_message),
+            body=_dumps(bot_message),
         )
 
     def sendSuccessNotification(self, reportType, reportName, totalRowsUpdated, bqTableName, message=None):
@@ -362,13 +362,13 @@ class CommonOperations:
 
         message_headers = {'Content-Type': 'application/json; charset=UTF-8'}
 
-        http_obj = Http()
+        http_obj = _Http()
 
         response = http_obj.request(
             uri=url,
             method='POST',
             headers=message_headers,
-            body=dumps(bot_message),
+            body=_dumps(bot_message),
         )
 
     def call_key(self):
@@ -377,7 +377,7 @@ class CommonOperations:
     def decrypt(self, encryptedString):
         try:
             key = self.call_key()
-            b = Fernet(key)
+            b = _Fernet(key)
             return b.decrypt(encryptedString.encode()).decode('utf-8')
         except Exception as ex:
             raise ex
@@ -386,13 +386,13 @@ class CommonOperations:
         try:
             key = self.call_key()
             encodedString = stringToEncrypt.encode()
-            a = Fernet(key)
+            a = _Fernet(key)
             return a.encrypt(encodedString).decode()
         except Exception as ex:
             raise ex
 
     def genwrite_key(self):
-        key = Fernet.generate_key()
+        key = _Fernet.generate_key()
         with open("pass.key", "wb") as key_file:
             key_file.write(key)
 
